@@ -50,7 +50,7 @@ var staticSuites = []*ginkgo.TestSuite{
 		The disruptive test suite.
 		`),
 		Matches: func(name string) bool {
-			return strings.Contains(name, "[Disruptive]") && strings.Contains(name, "[dr-quorum-restore]")
+			return strings.Contains(name, "[Disruptive]") && strings.Contains(name, "[Feature:EtcdRecovery]")
 		},
 		TestTimeout: 60 * time.Minute,
 	},
@@ -94,7 +94,7 @@ var staticSuites = []*ginkgo.TestSuite{
 		Tests that exercise the OpenShift image-registry functionality.
 		`),
 		Matches: func(name string) bool {
-			return strings.Contains(name, "[registry]") && !strings.Contains(name, "[Local]")
+			return strings.Contains(name, "[sig-imageregistry]") && !strings.Contains(name, "[Local]")
 		},
 	},
 	{
@@ -103,7 +103,7 @@ var staticSuites = []*ginkgo.TestSuite{
 		Tests that exercise language and tooling images shipped as part of OpenShift.
 		`),
 		Matches: func(name string) bool {
-			return strings.Contains(name, "[image_ecosystem]") && !strings.Contains(name, "[Local]")
+			return strings.Contains(name, "[Feature:ImageEcosystem]") && !strings.Contains(name, "[Local]")
 		},
 		Parallelism: 7,
 		TestTimeout: 20 * time.Minute,
@@ -120,6 +120,16 @@ var staticSuites = []*ginkgo.TestSuite{
 		TestTimeout: 20 * time.Minute,
 	},
 	{
+		Name: "openshift/jenkins-e2e-rhel-only",
+		Description: templates.LongDesc(`
+		Tests that exercise the OpenShift / Jenkins integrations provided by the OpenShift Jenkins image/plugins and the Pipeline Build Strategy.
+		`),
+		Matches: func(name string) bool {
+			return strings.Contains(name, "[Feature:JenkinsRHELImagesOnly]")
+		},
+		Parallelism: 4,
+		TestTimeout: 20 * time.Minute,
+	}, {
 		Name: "openshift/scalability",
 		Description: templates.LongDesc(`
 		Tests that verify the scalability characteristics of the cluster. Currently this is focused on core performance behaviors and preventing regressions.
@@ -142,13 +152,20 @@ var staticSuites = []*ginkgo.TestSuite{
 		Description: templates.LongDesc(`
 		Run only tests for test-cmd.
 		`),
-		Matches: func(name string) bool { return strings.Contains(name, "[Suite:openshift/test-cmd]") },
+		Matches: func(name string) bool { return strings.Contains(name, "[Feature:LegacyCommandTests]") },
 	},
 	{
 		Name: "openshift/csi",
 		Description: templates.LongDesc(`
-		Run tests for an installed CSI driver. TEST_CSI_DRIVER_FILES env. variable must be set and it must be a comma separated list of CSI driver definition files.
-        See https://github.com/kubernetes/kubernetes/blob/master/test/e2e/storage/external/README.md for required format of the files.
+		Run tests for an CSI driver. Set the TEST_INSTALL_CSI_DRIVERS environment variable to the name of the driver to load.
+		For example, TEST_INSTALL_CSI_DRIVERS=aws-ebs will test the AWS EBS CSI driver. To change the location of the images,
+		specify IMAGE_FORMAT=myregistry.com/myrepository/${component}:4.5 where ${component} will be substituted with the
+		names of required CSI component images:
+
+			csi-external-attacher, csi-external-provisioner, csi-external-resizer,
+			csi-external-snapshotter, csi-node-driver-registrar, csi-livenessprobe
+
+		See https://github.com/kubernetes/kubernetes/blob/master/test/e2e/storage/external/README.md for required format of the files.
 		`),
 		Matches: func(name string) bool {
 			return strings.Contains(name, "External Storage [Driver:") && !strings.Contains(name, "[Disruptive]")
