@@ -237,10 +237,12 @@ func testEtcd3StoragePath(t g.GinkgoTInterface, kubeConfig *restclient.Config, e
 	etcddata.CreateTestCRDs(tt, crdClient, false, etcddata.GetCustomResourceDefinitionData()...)
 	defer func() {
 		deleteCRD := crdClient.ApiextensionsV1beta1().CustomResourceDefinitions().Delete
+		ctx := context.Background()
+		delOptions := metav1.DeleteOptions{}
 		if err := errors.NewAggregate([]error{
-			deleteCRD("foos.cr.bar.com", nil),
-			deleteCRD("pandas.awesome.bears.com", nil),
-			deleteCRD("pants.custom.fancy.com", nil),
+			deleteCRD(ctx, "foos.cr.bar.com", delOptions),
+			deleteCRD(ctx, "pandas.awesome.bears.com", delOptions),
+			deleteCRD(ctx, "pants.custom.fancy.com", delOptions),
 		}); err != nil {
 			t.Fatal(err)
 		}
@@ -253,11 +255,11 @@ func testEtcd3StoragePath(t g.GinkgoTInterface, kubeConfig *restclient.Config, e
 
 	client := &allClient{dynamicClient: dynamic.NewForConfigOrDie(kubeConfig)}
 
-	if _, err := kubeClient.CoreV1().Namespaces().Create(&kapiv1.Namespace{ObjectMeta: metav1.ObjectMeta{Name: testNamespace}}); err != nil {
+	if _, err := kubeClient.CoreV1().Namespaces().Create(context.Background(), &kapiv1.Namespace{ObjectMeta: metav1.ObjectMeta{Name: testNamespace}}, metav1.CreateOptions{}); err != nil {
 		t.Fatalf("error creating test namespace: %#v", err)
 	}
 	defer func() {
-		if err := kubeClient.CoreV1().Namespaces().Delete(testNamespace, nil); err != nil {
+		if err := kubeClient.CoreV1().Namespaces().Delete(context.Background(), testNamespace, metav1.DeleteOptions{}); err != nil {
 			t.Fatalf("error deleting test namespace: %#v", err)
 		}
 	}()
@@ -276,21 +278,16 @@ func testEtcd3StoragePath(t g.GinkgoTInterface, kubeConfig *restclient.Config, e
 		gvr("scheduling.k8s.io", "v1alpha1", "priorityclasses"),
 		gvr("settings.k8s.io", "v1alpha1", "podpresets"),
 		gvr("storage.k8s.io", "v1alpha1", "volumeattachments"),
-		gvr("extensions", "v1beta1", "deployments"),
-		gvr("extensions", "v1beta1", "podsecuritypolicies"),
-		gvr("extensions", "v1beta1", "replicasets"),
-		gvr("extensions", "v1beta1", "daemonsets"),
-		gvr("extensions", "v1beta1", "networkpolicies"),
-		gvr("apps", "v1beta2", "deployments"),
-		gvr("apps", "v1beta2", "replicasets"),
-		gvr("apps", "v1beta2", "controllerrevisions"),
-		gvr("apps", "v1beta2", "statefulsets"),
-		gvr("apps", "v1beta2", "daemonsets"),
-		gvr("apps", "v1beta1", "controllerrevisions"),
-		gvr("apps", "v1beta1", "statefulsets"),
-		gvr("apps", "v1beta1", "deployments"),
 	)
 
+	// flowcontrol may or may not be on.  This allows us to ratchet in turning it on.
+	if flowControlResources, err := kubeClient.Discovery().ServerResourcesForGroupVersion("flowcontrol.apiserver.k8s.io/v1alpha1"); err != nil || len(flowControlResources.APIResources) == 0 {
+		removeStorageData(t, etcdStorageData,
+			gvr("flowcontrol.apiserver.k8s.io", "v1alpha1", "flowschemas"),
+			gvr("flowcontrol.apiserver.k8s.io", "v1alpha1", "prioritylevelconfigurations"),
+		)
+	}
+
 	// we use a different default path prefix for kube resources
 	for gvr := range etcdStorageData {
 		data := etcdStorageData[gvr]
@@ -449,7 +446,7 @@ func testEtcd3StoragePath(t g.GinkgoTInterface, kubeConfig *restclient.Config, e
 }
 
 func getCRDs(t g.GinkgoTInterface, crdClient *apiextensionsclientset.Clientset) map[schema.GroupVersionResource]empty {
-	crdList, err := crdClient.ApiextensionsV1beta1().CustomResourceDefinitions().List(metav1.ListOptions{})
+	crdList, err := crdClient.ApiextensionsV1beta1().CustomResourceDefinitions().List(context.Background(), metav1.ListOptions{})
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -590,7 +587,7 @@ func (c *allClient) create(stub, ns string, mapping *meta.RESTMapping, all *[]cl
 		return err
 	}
 
-	actual, err := resourceClient.Create(obj, metav1.CreateOptions{})
+	actual, err := resourceClient.Create(context.Background(), obj, metav1.CreateOptions{})
 	if err != nil {
 		return err
 	}
@@ -605,7 +602,7 @@ func (c *allClient) cleanup(all *[]cleanupData) error {
 		obj := (*all)[i].obj
 		gvr := (*all)[i].resource
 
-		if err := c.dynamicClient.Resource(gvr).Namespace(obj.GetNamespace()).Delete(obj.GetName(), nil); err != nil {
+		if err := c.dynamicClient.Resource(gvr).Namespace(obj.GetNamespace()).Delete(context.Background(), obj.GetName(), metav1.DeleteOptions{}); err != nil {
 			return err
 		}
 	}
