@@ -1,6 +1,7 @@
 package operators
 
 import (
+	"context"
 	"fmt"
 	"strings"
 
@@ -13,12 +14,12 @@ import (
 	e2e "k8s.io/kubernetes/test/e2e/framework"
 )
 
-var _ = Describe("[Feature:Platform] Managed cluster should", func() {
+var _ = Describe("[sig-arch] Managed cluster should", func() {
 	oc := exutil.NewCLIWithoutNamespace("operators")
 
 	It("ensure control plane pods do not run in best-effort QoS", func() {
 		// iterate over the references to find valid images
-		pods, err := oc.KubeFramework().ClientSet.CoreV1().Pods("").List(metav1.ListOptions{})
+		pods, err := oc.KubeFramework().ClientSet.CoreV1().Pods("").List(context.Background(), metav1.ListOptions{})
 		if err != nil {
 			e2e.Failf("unable to list pods: %v", err)
 		}
@@ -29,7 +30,12 @@ var _ = Describe("[Feature:Platform] Managed cluster should", func() {
 		// TODO components in openshift-operators may not come from our payload, may want to weaken restriction
 		namespacePrefixes := sets.NewString("kube-", "openshift-")
 		excludeNamespaces := sets.NewString("openshift-operator-lifecycle-manager")
-		excludePodPrefix := sets.NewString("revision-pruner-", "installer-", "must-gather-")
+		excludePodPrefix := sets.NewString(
+			"revision-pruner-",  // operators have retry logic built in. these are like jobs but cannot rely on jobs
+			"installer-",        // operators have retry logic built in. these are like jobs but cannot rely on jobs
+			"must-gather-",      // operators have retry logic built in. these are like jobs but cannot rely on jobs
+			"recycler-for-nfs-", // recyclers are allowed to fail.  I guess a cluster-admin works out that he needs to take manual action.  sig-storage
+		)
 		for _, pod := range pods.Items {
 			// exclude non-control plane namespaces
 			if !hasPrefixSet(pod.Namespace, namespacePrefixes) {
