@@ -1,12 +1,21 @@
 package project
 
 import (
+	"context"
 	"fmt"
 	"time"
 
+	"github.com/davecgh/go-spew/spew"
 	g "github.com/onsi/ginkgo"
 	o "github.com/onsi/gomega"
-
+	"github.com/openshift/api/annotations"
+	authorizationv1 "github.com/openshift/api/authorization/v1"
+	oauthv1 "github.com/openshift/api/oauth/v1"
+	projectv1 "github.com/openshift/api/project/v1"
+	"github.com/openshift/apiserver-library-go/pkg/authorization/scope"
+	projectv1client "github.com/openshift/client-go/project/clientset/versioned/typed/project/v1"
+	"github.com/openshift/origin/test/extended/authorization"
+	exutil "github.com/openshift/origin/test/extended/util"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -16,20 +25,12 @@ import (
 	"k8s.io/apimachinery/pkg/watch"
 	"k8s.io/client-go/rest"
 	"k8s.io/kubernetes/test/e2e/framework"
-
-	"github.com/openshift/api/annotations"
-	authorizationv1 "github.com/openshift/api/authorization/v1"
-	oauthv1 "github.com/openshift/api/oauth/v1"
-	projectv1 "github.com/openshift/api/project/v1"
-	"github.com/openshift/apiserver-library-go/pkg/authorization/scope"
-	projectv1client "github.com/openshift/client-go/project/clientset/versioned/typed/project/v1"
-	"github.com/openshift/origin/test/extended/authorization"
-	exutil "github.com/openshift/origin/test/extended/util"
 )
 
-var _ = g.Describe("[Feature:ProjectAPI] ", func() {
+var _ = g.Describe("[sig-auth][Feature:ProjectAPI] ", func() {
 	defer g.GinkgoRecover()
-	oc := exutil.NewCLI("project-api", exutil.KubeConfigPath())
+	oc := exutil.NewCLI("project-api")
+	ctx := context.Background()
 
 	g.Describe("TestProjectIsNamespace", func() {
 		g.It(fmt.Sprintf("should succeed"), func() {
@@ -39,14 +40,14 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 			namespace := &corev1.Namespace{
 				ObjectMeta: metav1.ObjectMeta{Name: "integration-test-" + oc.Namespace()},
 			}
-			namespaceResult, err := oc.AdminKubeClient().CoreV1().Namespaces().Create(namespace)
+			namespaceResult, err := oc.AdminKubeClient().CoreV1().Namespaces().Create(ctx, namespace, metav1.CreateOptions{})
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
 			oc.AddResourceToDelete(corev1.SchemeGroupVersion.WithResource("namespaces"), namespaceResult)
 
 			// now try to get the project with the same name and ensure it is our namespace
-			project, err := oc.AdminProjectClient().ProjectV1().Projects().Get(namespaceResult.Name, metav1.GetOptions{})
+			project, err := oc.AdminProjectClient().ProjectV1().Projects().Get(ctx, namespaceResult.Name, metav1.GetOptions{})
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
@@ -64,14 +65,14 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 					},
 				},
 			}
-			projectResult, err := oc.AdminProjectClient().ProjectV1().Projects().Create(project)
+			projectResult, err := oc.AdminProjectClient().ProjectV1().Projects().Create(ctx, project, metav1.CreateOptions{})
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
 			oc.AddResourceToDelete(projectv1.GroupVersion.WithResource("projects"), projectResult)
 
 			// now get the namespace for that project
-			namespace, err = oc.AdminKubeClient().CoreV1().Namespaces().Get(projectResult.Name, metav1.GetOptions{})
+			namespace, err = oc.AdminKubeClient().CoreV1().Namespaces().Get(ctx, projectResult.Name, metav1.GetOptions{})
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
@@ -88,16 +89,18 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 	})
 })
 
-var _ = g.Describe("[Feature:ProjectAPI] ", func() {
+var _ = g.Describe("[sig-auth][Feature:ProjectAPI] ", func() {
+	ctx := context.Background()
+
 	defer g.GinkgoRecover()
-	oc := exutil.NewCLI("project-api", exutil.KubeConfigPath())
+	oc := exutil.NewCLI("project-api")
 
 	g.Describe("TestProjectWatch", func() {
 		g.It(fmt.Sprintf("should succeed"), func() {
 			bobName := oc.CreateUser("bob-").Name
 			bobConfig := oc.GetClientConfigForUser(bobName)
 			bobProjectClient := projectv1client.NewForConfigOrDie(bobConfig)
-			w, err := bobProjectClient.Projects().Watch(metav1.ListOptions{})
+			w, err := bobProjectClient.Projects().Watch(ctx, metav1.ListOptions{})
 			o.Expect(err).NotTo(o.HaveOccurred())
 
 			ns01Name := oc.CreateProject()
@@ -111,7 +114,7 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 			bobEditName := authorization.AddUserEditToProject(oc, ns02Name, bobName)
 			waitForAdd(ns02Name, w)
 
-			err = oc.AdminAuthorizationClient().AuthorizationV1().RoleBindings(ns02Name).Delete(bobEditName, nil)
+			err = oc.AdminAuthorizationClient().AuthorizationV1().RoleBindings(ns02Name).Delete(ctx, bobEditName, metav1.DeleteOptions{})
 			o.Expect(err).NotTo(o.HaveOccurred())
 
 			waitForDelete(ns02Name, w)
@@ -121,21 +124,21 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 			authorization.AddUserAdminToProject(oc, ns03Name, bobName)
 			waitForAdd(ns03Name, w)
 
-			bobProjectClient.Projects().Delete(ns03Name, nil)
+			bobProjectClient.Projects().Delete(ctx, ns03Name, metav1.DeleteOptions{})
 			o.Expect(err).NotTo(o.HaveOccurred())
 
 			// wait for the delete
 			waitForDelete(ns03Name, w)
 
 			// test the "start from beginning watch"
-			beginningWatch, err := bobProjectClient.Projects().Watch(metav1.ListOptions{ResourceVersion: "0"})
+			beginningWatch, err := bobProjectClient.Projects().Watch(ctx, metav1.ListOptions{ResourceVersion: "0"})
 			o.Expect(err).NotTo(o.HaveOccurred())
 			waitForAdd(ns01Name, beginningWatch)
 
 			// Background: in HA we have no guarantee that watch caches are synchronized and this test already broke on Azure.
 			// Ref: https://bugzilla.redhat.com/show_bug.cgi?id=1744105
 			time.Sleep(5 * time.Second)
-			fromNowWatch, err := bobProjectClient.Projects().Watch(metav1.ListOptions{})
+			fromNowWatch, err := bobProjectClient.Projects().Watch(ctx, metav1.ListOptions{})
 			o.Expect(err).NotTo(o.HaveOccurred())
 			select {
 			case event := <-fromNowWatch.ResultChan():
@@ -147,9 +150,11 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 	})
 })
 
-var _ = g.Describe("[Feature:ProjectAPI] ", func() {
+var _ = g.Describe("[sig-auth][Feature:ProjectAPI] ", func() {
+	ctx := context.Background()
+
 	defer g.GinkgoRecover()
-	oc := exutil.NewCLI("project-api", exutil.KubeConfigPath())
+	oc := exutil.NewCLI("project-api")
 
 	g.Describe("TestProjectWatchWithSelectionPredicate", func() {
 		g.It(fmt.Sprintf("should succeed"), func() {
@@ -158,7 +163,7 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 			bobProjectClient := projectv1client.NewForConfigOrDie(bobConfig)
 
 			ns01Name := oc.CreateProject()
-			w, err := bobProjectClient.Projects().Watch(metav1.ListOptions{
+			w, err := bobProjectClient.Projects().Watch(ctx, metav1.ListOptions{
 				FieldSelector: "metadata.name=" + ns01Name,
 			})
 			o.Expect(err).NotTo(o.HaveOccurred())
@@ -172,14 +177,14 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 			// we are only watching ns-01, we should not receive events for other projects
 			waitForNoEvent(w, ns01Name)
 
-			bobProjectClient.Projects().Delete(ns03Name, nil)
+			bobProjectClient.Projects().Delete(ctx, ns03Name, metav1.DeleteOptions{})
 			o.Expect(err).NotTo(o.HaveOccurred())
 
 			// we are only watching ns-01, we should not receive events for other projects
 			waitForNoEvent(w, ns01Name)
 
 			// test the "start from beginning watch"
-			beginningWatch, err := bobProjectClient.Projects().Watch(metav1.ListOptions{
+			beginningWatch, err := bobProjectClient.Projects().Watch(ctx, metav1.ListOptions{
 				ResourceVersion: "0",
 				FieldSelector:   "metadata.name=" + ns01Name,
 			})
@@ -187,7 +192,7 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 			// we should be seeing an "ADD" watch event being emitted, since we are specifically watching this project via a field selector
 			waitForAdd(ns01Name, beginningWatch)
 
-			fromNowWatch, err := bobProjectClient.Projects().Watch(metav1.ListOptions{
+			fromNowWatch, err := bobProjectClient.Projects().Watch(ctx, metav1.ListOptions{
 				FieldSelector: "metadata.name=" + ns01Name,
 			})
 			o.Expect(err).NotTo(o.HaveOccurred())
@@ -286,9 +291,18 @@ func waitForOnlyDelete(projectName string, w watch.Interface) {
 		hasTerminated := sets.NewString()
 		for {
 			select {
-			case event := <-w.ResultChan():
-				project := event.Object.(*projectv1.Project)
+			case event, ok := <-w.ResultChan():
+				if !ok {
+					g.Fail("watch was closed")
+				}
+
+				project, isProject := event.Object.(*projectv1.Project)
+				if !isProject {
+					framework.Logf("got a not-project %v %v", event.Type, spew.Sdump(event.Object))
+					continue
+				}
 				framework.Logf("got %#v %#v", event, project)
+
 				if project.Name == projectName {
 					if event.Type == watch.Deleted {
 						return
@@ -311,16 +325,18 @@ func waitForOnlyDelete(projectName string, w watch.Interface) {
 				}
 				g.Fail(fmt.Sprintf("got unexpected project %v", project.Name))
 
-			case <-time.After(30 * time.Second):
+			case <-time.After(time.Minute):
 				g.Fail(fmt.Sprintf("timeout: %v", projectName))
 			}
 		}
 	})
 }
 
-var _ = g.Describe("[Feature:ProjectAPI] ", func() {
+var _ = g.Describe("[sig-auth][Feature:ProjectAPI] ", func() {
+	ctx := context.Background()
+
 	defer g.GinkgoRecover()
-	oc := exutil.NewCLI("project-api", exutil.KubeConfigPath())
+	oc := exutil.NewCLI("project-api")
 
 	g.Describe("TestScopedProjectAccess", func() {
 		g.It(fmt.Sprintf("should succeed"), func() {
@@ -361,15 +377,15 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 			}
 			allBobClient := projectv1client.NewForConfigOrDie(allBobConfig)
 
-			oneTwoWatch, err := oneTwoBobClient.Projects().Watch(metav1.ListOptions{})
+			oneTwoWatch, err := oneTwoBobClient.Projects().Watch(ctx, metav1.ListOptions{})
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
-			twoThreeWatch, err := twoThreeBobClient.Projects().Watch(metav1.ListOptions{})
+			twoThreeWatch, err := twoThreeBobClient.Projects().Watch(ctx, metav1.ListOptions{})
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
-			allWatch, err := allBobClient.Projects().Watch(metav1.ListOptions{})
+			allWatch, err := allBobClient.Projects().Watch(ctx, metav1.ListOptions{})
 			if err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
@@ -405,25 +421,27 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 				t.Error(err)
 			}
 
-			if err := fullBobClient.Projects().Delete(fourName, nil); err != nil {
+			delOptions := metav1.DeleteOptions{}
+
+			if err := fullBobClient.Projects().Delete(ctx, fourName, delOptions); err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
 			waitForOnlyDelete(fourName, allWatch)
 
-			if err := fullBobClient.Projects().Delete(threeName, nil); err != nil {
+			if err := fullBobClient.Projects().Delete(ctx, threeName, delOptions); err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
 			waitForOnlyDelete(threeName, allWatch)
 			waitForOnlyDelete(threeName, twoThreeWatch)
 
-			if err := fullBobClient.Projects().Delete(twoName, nil); err != nil {
+			if err := fullBobClient.Projects().Delete(ctx, twoName, delOptions); err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
 			waitForOnlyDelete(twoName, allWatch)
 			waitForOnlyDelete(twoName, oneTwoWatch)
 			waitForOnlyDelete(twoName, twoThreeWatch)
 
-			if err := fullBobClient.Projects().Delete(oneName, nil); err != nil {
+			if err := fullBobClient.Projects().Delete(ctx, oneName, delOptions); err != nil {
 				t.Fatalf("unexpected error: %v", err)
 			}
 			waitForOnlyDelete(oneName, allWatch)
@@ -432,9 +450,11 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 	})
 })
 
-var _ = g.Describe("[Feature:ProjectAPI] ", func() {
+var _ = g.Describe("[sig-auth][Feature:ProjectAPI] ", func() {
+	ctx := context.Background()
+
 	defer g.GinkgoRecover()
-	oc := exutil.NewCLI("project-api", exutil.KubeConfigPath())
+	oc := exutil.NewCLI("project-api")
 
 	g.Describe("TestInvalidRoleRefs", func() {
 		g.It(fmt.Sprintf("should succeed"), func() {
@@ -458,17 +478,17 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 			roleBinding.RoleRef.Name = "missing-role-" + oc.Namespace()
 
 			// mess up rolebindings in "foo"
-			_, err := clusterAdminRbacClient.RoleBindings(fooName).Create(roleBinding)
+			_, err := clusterAdminRbacClient.RoleBindings(fooName).Create(ctx, roleBinding, metav1.CreateOptions{})
 			o.Expect(err).NotTo(o.HaveOccurred())
 			// mess up rolebindings in "bar"
-			_, err = clusterAdminRbacClient.RoleBindings(barName).Create(roleBinding)
+			_, err = clusterAdminRbacClient.RoleBindings(barName).Create(ctx, roleBinding, metav1.CreateOptions{})
 			o.Expect(err).NotTo(o.HaveOccurred())
 			// mess up clusterrolebindings
 			clusterRoleBinding := &rbacv1.ClusterRoleBinding{}
 			clusterRoleBinding.GenerateName = "missing-role-"
 			clusterRoleBinding.RoleRef.Kind = "ClusterRole"
 			clusterRoleBinding.RoleRef.Name = "missing-role-" + oc.Namespace()
-			actual, err := clusterAdminRbacClient.ClusterRoleBindings().Create(clusterRoleBinding)
+			actual, err := clusterAdminRbacClient.ClusterRoleBindings().Create(ctx, clusterRoleBinding, metav1.CreateOptions{})
 			o.Expect(err).NotTo(o.HaveOccurred())
 			oc.AddResourceToDelete(rbacv1.SchemeGroupVersion.WithResource("clusterrolebindings"), actual)
 
@@ -478,15 +498,15 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 				for i := 0; i < 10; i++ {
 					review := &authorizationv1.ResourceAccessReview{Action: authorizationv1.Action{Verb: "get", Resource: "pods"}}
 					review.Action.Namespace = fooName
-					if resp, err := clusterAdminAuthorizationClient.ResourceAccessReviews().Create(review); err != nil || resp.EvaluationError == "" {
+					if resp, err := clusterAdminAuthorizationClient.ResourceAccessReviews().Create(ctx, review, metav1.CreateOptions{}); err != nil || resp.EvaluationError == "" {
 						return false, err
 					}
 					review.Action.Namespace = barName
-					if resp, err := clusterAdminAuthorizationClient.ResourceAccessReviews().Create(review); err != nil || resp.EvaluationError == "" {
+					if resp, err := clusterAdminAuthorizationClient.ResourceAccessReviews().Create(ctx, review, metav1.CreateOptions{}); err != nil || resp.EvaluationError == "" {
 						return false, err
 					}
 					review.Action.Namespace = ""
-					if resp, err := clusterAdminAuthorizationClient.ResourceAccessReviews().Create(review); err != nil || resp.EvaluationError == "" {
+					if resp, err := clusterAdminAuthorizationClient.ResourceAccessReviews().Create(ctx, review, metav1.CreateOptions{}); err != nil || resp.EvaluationError == "" {
 						return false, err
 					}
 				}
@@ -504,7 +524,7 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 
 			// Make sure cluster admin still sees all projects, we sometimes appear to race, so wait for a second for caches
 			time.Sleep(1 * time.Second)
-			projects, err := oc.AdminProjectClient().ProjectV1().Projects().List(metav1.ListOptions{})
+			projects, err := oc.AdminProjectClient().ProjectV1().Projects().List(ctx, metav1.ListOptions{})
 			o.Expect(err).NotTo(o.HaveOccurred())
 
 			projectNames := sets.NewString()
@@ -522,7 +542,7 @@ var _ = g.Describe("[Feature:ProjectAPI] ", func() {
 func hasExactlyTheseProjects(lister projectv1client.ProjectInterface, projects sets.String) error {
 	var lastErr error
 	if err := wait.PollImmediate(100*time.Millisecond, 10*time.Second, func() (bool, error) {
-		list, err := lister.List(metav1.ListOptions{})
+		list, err := lister.List(context.Background(), metav1.ListOptions{})
 		if err != nil {
 			return false, err
 		}
@@ -545,7 +565,7 @@ func hasExactlyTheseProjects(lister projectv1client.ProjectInterface, projects s
 
 func GetScopedClientForUser(oc *exutil.CLI, username string, scopes []string) (*rest.Config, error) {
 	// make sure the user exists
-	user, err := oc.AdminUserClient().UserV1().Users().Get(username, metav1.GetOptions{})
+	user, err := oc.AdminUserClient().UserV1().Users().Get(context.Background(), username, metav1.GetOptions{})
 	if err != nil {
 		return nil, err
 	}
@@ -559,7 +579,7 @@ func GetScopedClientForUser(oc *exutil.CLI, username string, scopes []string) (*
 		UserName:    user.Name,
 		UserUID:     string(user.UID),
 	}
-	if _, err := oc.AdminOauthClient().OauthV1().OAuthAccessTokens().Create(token); err != nil {
+	if _, err := oc.AdminOauthClient().OauthV1().OAuthAccessTokens().Create(context.Background(), token, metav1.CreateOptions{}); err != nil {
 		return nil, err
 	}
 	oc.AddResourceToDelete(oauthv1.GroupVersion.WithResource("oauthaccesstokens"), token)
